==> client-sdk-react-0.59.0.tgz: package/src/components/Participant/Participant.tsx <==
import React from 'react'
import classNames from 'classnames'
import { ParticipantModel } from '../../models'
import { useParticipant } from '../../store'
import { Audio, Video } from '../Media'
import './Participant.scss'

export const Participant: React.FC<{ participant: ParticipantModel; withAudio?: boolean }> = ({
  participant,
  withAudio = false,
}) => {
  const {
    name,
    tracks: { primaryVideoTrack, primaryAudioTrack },
    isLocal,
    connectionQuality,
    isSpeaking,
  } = useParticipant(participant)

  const videoIsMuted = !primaryVideoTrack || primaryVideoTrack.isMuted
  const audioIsMuted = !primaryAudioTrack || primaryAudioTrack.isMuted

  return (
    <div className='participant'>
      <div className='participant__name'>{name}</div>
      <div
        className={classNames('participant__video-container', {
          'participant__video-container--speaking': isSpeaking,
          'participant__video-container--local': isLocal,
        })}
      >
        {videoIsMuted ? (
          <div className='participant__avatar'>{name?.slice(0, 1) || ''}</div>
        ) : (
          <Video videoStream={primaryVideoTrack.track} />
        )}
      </div>
      <div className='participant__status-icons'>
        {videoIsMuted && <div className='participant__no-video-icon' />}
        {audioIsMuted && <div className='participant__no-audio-icon' />}
        <div className={`participant__${connectionQuality}-quality-icon`} />
      </div>
      {withAudio && !audioIsMuted && !isLocal && <Audio audioStream={primaryAudioTrack.track} />}
    </div>
  )
}

==> client-sdk-react-1.0.0.tgz: package/src/components/Participant/Participant.tsx <==
import React from 'react'
import classNames from 'classnames'
import { useParticipant } from '../../store'
import { Audio, Video } from '../Media'
import { ParticipantProps } from './model'
import './Participant.scss'

export const Participant: React.FC<ParticipantProps> = ({ participant, withAudio = false, extensionElement }) => {
  const {
    name,
    tracks: { primaryVideoTrack, primaryAudioTrack },
    isLocal,
    connectionQuality,
    isSpeaking,
  } = useParticipant(participant)

  const videoIsMuted = !primaryVideoTrack || primaryVideoTrack.isMuted
  const audioIsMuted = !primaryAudioTrack || primaryAudioTrack.isMuted

  const ExtensionElement = extensionElement || null

  return (
    <div className='participant'>
      <div className='participant__name'>{name}</div>
      <div
        className={classNames('participant__video-container', {
          'participant__video-container--speaking': isSpeaking,
          'participant__video-container--local': isLocal,
        })}
      >
        {videoIsMuted ? (
          <div className='participant__avatar'>{name?.slice(0, 1) || ''}</div>
        ) : (
          <Video videoStream={primaryVideoTrack.track} />
        )}
      </div>
      <div className='participant__status-icons'>
        {videoIsMuted && <div className='participant__no-video-icon' />}
        {audioIsMuted && <div className='participant__no-audio-icon' />}
        <div className={`participant__${connectionQuality}-quality-icon`} />
      </div>
      {ExtensionElement && (
        <ExtensionElement
          name={name}
          isLocal={isLocal}
          isSpeaking={isSpeaking}
          connectionQuality={connectionQuality}
          videoIsMuted={videoIsMuted}
          audioIsMuted={audioIsMuted}
        />
      )}
      {withAudio && !audioIsMuted && !isLocal && <Audio audioStream={primaryAudioTrack.track} />}
    </div>
  )
}
